from setuptools import setup

setup(
    name = 'anshika', # while installing pacakge, e.g., matplotlib...
    version = '0.0.1',
    description = 'Simple Bank Account.',
    long_description = open('Readme.txt').read(),
    url = 'https://github.com/anshika-rai123/',
    author = 'Anshika Rai',
    keywords = ['account', 'bank', 'class', 'ideationology'],
    packages = ['anshi'], # while importing package, e.g., pyplot...
)
